==> vee_2.4-6.tar.gz: vee-2.4/src/Setting.py <==
# -*- coding: utf-8 -*-
#    Copyright 2005 Spike^ekipS <spikeekips@gmail.com>
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import Conf, GConf, func, os

class DATA :

	DATA = dict()

	def __init__ (self, data=dict()) :
		self.DATA = data

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.set_path(Conf.LOCAL_ROOT)
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

	def get_value (self, key) :
		if self.DATA.has_key(key) :
			return self.DATA[key]
		else :
			raise KeyError, "Key, %s does not exists." % key

	def set_value (self, key, value) :
		self.DATA[key] = value

	#################################################################
	# DATA DRIVEN
	def get_system_default_font (self) :

		if self.DATA.has_key("use-system-default-font") and \
				self.DATA["use-system-default-font"] == True :
			__fontname = \
				self.GCONF_CLIENT.get_value(Conf.GLOBAL_FONT_SYSTEM_DEFAULT)
		elif self.DATA.has_key("font") and self.DATA["font"] :
			__fontname = self.DATA["font"]
		else :
			__fontname = self.GCONF_CLIENT.get_value_by_conf("font")

		return __fontname

	def get_max_scroll_line (self) :
		if self.DATA.has_key("max-scroll-line") and \
				type(self.DATA["max-scroll-line"]) is int :
			__max_scroll_line = self.DATA["max-scroll-line"]
		else :
			__max_scroll_line = \
				self.GCONF_CLIENT.get_value_by_conf("max-scrollline")

		return __max_scroll_line

	def get_color_foreground (self) :
		if self.DATA.has_key("color-foreground") :
			__c = self.DATA["color-foreground"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-foreground"]["key"])

		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_background (self) :
		if self.DATA.has_key("color-background") :
			__c = self.DATA["color-background"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-background"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_dim (self) :
		if self.DATA.has_key("color-dim") :
			__c = self.DATA["color-dim"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-dim"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_highlight (self) :
		if self.DATA.has_key("color-highlight") :
			__c = self.DATA["color-highlight"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-highlight"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_cursor (self) :
		if self.DATA.has_key("color-cursor") :
			__c = self.DATA["color-cursor"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-cursor"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_command_vim (self) :
		if self.DATA.has_key("command") and \
				self.DATA["command"].strip() :
			__fork_command = self.DATA["command"]
		else :
			__fork_command = \
				self.GCONF_CLIENT.get_value_by_conf("command-vim")

		return __fork_command

	def get_command_terminal (self) :
		if self.DATA.has_key("command") and \
				self.DATA["command"].strip() :
			__fork_command = self.DATA["command"]
		else :
			__fork_command = \
				self.GCONF_CLIENT.get_value(Conf.SCHEMA["command-terminal"]["key"])

		return __fork_command

	def get_vte_background (self) :

		__type = self.__get_vte_background_type()

		__shade = self.__get_vte_background_shade()
		if not __shade : __shade = 0.0

		if __type == "image-file" :
			__image_file = self.__get_vte_background_image_file()

			if not __image_file :
				return (None, None)
			elif not os.path.isfile(__image_file) :
				return (None, None)
			else :
				return ("image-file", (__image_file, __shade,))
		elif __type == "transparent" :
			return ("transparent", __shade)
		else :
			return (None, None)

	def __get_vte_background_type (self) :
		if self.DATA.has_key("vte-background-type") and \
				self.DATA["vte-background-type"].strip() :
			__value = self.DATA["vte-background-type"]
		else :
			__value = \
				self.GCONF_CLIENT.get_value_by_conf("vte-background-type")

		return __value

	def __get_vte_background_image_file (self) :
		if self.DATA.has_key("vte-background-image-file") and \
				self.DATA["vte-background-image-file"].strip() :
			__value = self.DATA["vte-background-image-file"]
		else :
			__value = None

		return __value

	def __get_vte_background_shade (self) :
		if self.DATA.has_key("vte-background-shade") and \
				type(self.DATA["vte-background-shade"]) is float :
			__value = self.DATA["vte-background-shade"]
		else :
			__value = \
				self.GCONF_CLIENT.get_value_by_conf("vte-background-shade")

		return round(__value, 2)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Setting.py"

==> vee_2.5-1.tar.gz: vee-2.5/src/Setting.py <==
# -*- coding: utf-8 -*-
#    Copyright 2005 Spike^ekipS <spikeekips@gmail.com>
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import Conf, GConf, func, os

class DATA :

	DATA = dict()

	def __init__ (self, data=dict()) :
		self.DATA = data

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.set_path(Conf.LOCAL_ROOT)
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

	def get_value (self, key) :
		if self.DATA.has_key(key) :
			return self.DATA[key]
		else :
			raise KeyError, "Key, %s does not exists." % key

	def set_value (self, key, value) :
		self.DATA[key] = value

	#################################################################
	# DATA DRIVEN
	def get_system_default_font (self) :

		if self.DATA.has_key("use-system-default-font") and \
				self.DATA["use-system-default-font"] == True :
			__fontname = \
				self.GCONF_CLIENT.get_value(Conf.GLOBAL_FONT_SYSTEM_DEFAULT)
		elif self.DATA.has_key("font") and self.DATA["font"] :
			__fontname = self.DATA["font"]
		else :
			__fontname = self.GCONF_CLIENT.get_value_by_conf("font")

		return __fontname

	def get_max_scroll_line (self) :
		if self.DATA.has_key("max-scroll-line") and \
				type(self.DATA["max-scroll-line"]) is int :
			__max_scroll_line = self.DATA["max-scroll-line"]
		else :
			__max_scroll_line = \
				self.GCONF_CLIENT.get_value_by_conf("max-scrollline")

		return __max_scroll_line

	def get_color_foreground (self) :
		if self.DATA.has_key("color-foreground") and \
				self.DATA["color-foreground"].strip() :
			__c = self.DATA["color-foreground"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-foreground"]["key"])

		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_background (self) :
		if self.DATA.has_key("color-background") and \
				self.DATA["color-background"].strip() :
			__c = self.DATA["color-background"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-background"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_dim (self) :
		if self.DATA.has_key("color-dim") and \
				self.DATA["color-dim"].strip() :
			__c = self.DATA["color-dim"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-dim"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_highlight (self) :
		if self.DATA.has_key("color-highlight") and \
				self.DATA["color-highlight"].strip() :
			__c = self.DATA["color-highlight"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-highlight"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_color_cursor (self) :
		if self.DATA.has_key("color-cursor") and \
				self.DATA["color-cursor"].strip() :
			__c = self.DATA["color-cursor"]
		else :
			__c = self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["color-cursor"]["key"])
		__c0 = func.str_to_color(__c)

		return __c0

	def get_command_vim (self) :
		if self.DATA.has_key("command") and \
				self.DATA["command"].strip() :
			__fork_command = self.DATA["command"]
		else :
			__fork_command = \
				self.GCONF_CLIENT.get_value_by_conf("command-vim")

		return __fork_command

	def get_command_terminal (self) :
		if self.DATA.has_key("command") and \
				self.DATA["command"].strip() :
			__fork_command = self.DATA["command"]
		else :
			__fork_command = \
				self.GCONF_CLIENT.get_value(Conf.SCHEMA["command-terminal"]["key"])

		return __fork_command

	def get_vte_background (self) :

		__type = self.__get_vte_background_type()

		__shade = self.__get_vte_background_shade()
		if not __shade : __shade = 0.0

		if __type == "image-file" :
			__image_file = self.__get_vte_background_image_file()

			if not __image_file :
				return (None, None)
			elif not os.path.isfile(__image_file) :
				return (None, None)
			else :
				return ("image-file", (__image_file, __shade,))
		elif __type == "transparent" :
			return ("transparent", __shade)
		else :
			return (None, None)

	def __get_vte_background_type (self) :
		if self.DATA.has_key("vte-background-type") and \
				self.DATA["vte-background-type"].strip() :
			__value = self.DATA["vte-background-type"]
		else :
			__value = \
				self.GCONF_CLIENT.get_value_by_conf("vte-background-type")

		return __value

	def __get_vte_background_image_file (self) :
		if self.DATA.has_key("vte-background-image-file") and \
				self.DATA["vte-background-image-file"].strip() :
			__value = self.DATA["vte-background-image-file"]
		else :
			__value = None

		return __value

	def __get_vte_background_shade (self) :
		if self.DATA.has_key("vte-background-shade") and \
				type(self.DATA["vte-background-shade"]) is float :
			__value = self.DATA["vte-background-shade"]
		else :
			__value = \
				self.GCONF_CLIENT.get_value_by_conf("vte-background-shade")

		return round(__value, 2)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Setting.py"
